BOOST_PP_LIST_CAT

The BOOST_PP_LIST_CAT macro concatenates all elements in a list.

#### Usage

BOOST_PP_LIST_CAT(list)

#### Arguments

list
  The list whose elements are to be concatenated.

#### Remarks

Elements are concatenated left-to-right starting with index 0.
Previously, this macro could not be used inside BOOST_PP_WHILE. There is no longer any such restriction. It is more efficient, however, to use BOOST_PP_LIST_CAT_D in such a situation.

#### See Also

- BOOST_PP_LIST_CAT_D

#### Requirements

Header: <boost/preprocessor/list/cat.hpp>

#### Sample Code

    #include <boost/preprocessor/list/cat.hpp>

    #define LIST (a, (b, (c, BOOST_PP_NIL)))

    BOOST_PP_LIST_CAT(LIST) // expands to abc

© Copyright Housemarque Oy 2002 © Copyright Paul Mensonides 2002

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)